@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.016-9-gf00f4b0
+package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.017-9-g9c24e71
 # ABSTRACT: Specify dynamic (user-side) prerequisites for your distribution
 # KEYWORDS: plugin distribution metadata MYMETA prerequisites Makefile.PL dynamic
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.017';
+our $VERSION = '0.018';
 
 use Moose;
 with
@@ -46,7 +46,7 @@ has raw => (
             };
         }
 
-        $self->log('no content found in -raw!') if not @lines;
+        $self->log('no content found in -raw/-body!') if not @lines;
         return \@lines;
     },
 );
@@ -71,6 +71,9 @@ sub mvp_aliases { +{
     '-raw_from_file' => 'raw_from_file',
     '-include_sub' => 'include_subs',
     '-condition' => 'conditions',
+    '-body' => 'raw',
+    '-body_from_file' => 'raw_from_file',
+    'body_from_file' => 'raw_from_file',
 } }
 
 around BUILDARGS => sub
@@ -239,6 +242,9 @@ my %sub_dependencies = (
     can_cc => [ qw(can_run) ],
     can_run => [ qw(maybe_command) ],
     requires => [ qw(runtime_requires) ],
+    runtime_requires => [ qw(_add_prereq) ],
+    build_requires => [ qw(_add_prereq) ],
+    test_requires => [ qw(_add_prereq) ],
 );
 
 has _all_required_subs => (
@@ -308,7 +314,7 @@ Dist::Zilla::Plugin::DynamicPrereqs - Specify dynamic (user-side) prerequisites
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 SYNOPSIS
 
@@ -318,7 +324,7 @@ In your F<dist.ini>:
     -condition = has_module('Role::Tiny')
     -condition = !parse_args()->{PUREPERL_ONLY}
     -condition = can_xs()
-    -raw = requires('Role::Tiny', '1.003000')
+    -body = requires('Role::Tiny', '1.003000')
 
 or:
 
@@ -371,6 +377,8 @@ Please also see the other warnings later in this document.
 
 =head2 C<-raw>
 
+=head2 C<-body>
+
 The code to be inserted; must be valid and complete perl statements. You can
 reference and modify the already-declared C<%WriteMakefileArgs> and
 C<%FallbackPrereqs> variables, as inserted into F<Makefile.PL> by
@@ -383,6 +391,8 @@ If you use external libraries in the code you are inserting, you B<must> add
 these modules to C<configure_requires> prereqs in metadata (e.g. via
 C<[Prereqs / ConfigureRequires]> in your F<dist.ini>).
 
+C<-body> first became available in version 0.018.
+
 =for Pod::Coverage mvp_multivalue_args mvp_aliases BUILD metadata after_build setup_installer register_prereqs
 
 =head2 C<-delimiter>
@@ -390,7 +400,7 @@ C<[Prereqs / ConfigureRequires]> in your F<dist.ini>).
 (Available since version 0.007)
 
 A string, usually a single character, which is stripped from the beginning of
-all C<-raw> lines. This is because the INI file format strips all leading
+all C<-raw>/C<-body> lines. This is because the INI file format strips all leading
 whitespace from option values, so including this character at the front allows
 you to use leading whitespace in an option string, so you can indent blocks of
 code properly.
@@ -399,8 +409,12 @@ code properly.
 
 (Available since version 0.010)
 
+=head2 C<-body_from_file>
+
+(Available since version 0.018)
+
 A filename that contains the code to be inserted; must be valid and complete
-perl statements, as with C<-raw> above.  This file must be part of the build,
+perl statements, as with C<-raw>/C<-body> above.  This file must be part of the build,
 but it is pruned from the built distribution.
 
 =head2 C<-condition>
@@ -416,12 +430,12 @@ appropriately parenthesize each of your conditions to ensure correct order of
 operations.)  Any use of recognized subroutines will cause their definitions
 to be included automatically (see L<AVAILABLE SUBROUTINE DEFINITIONS>, below).
 
-When combined with C<-raw> lines, the condition is placed first in a C<if>
-statement, and the C<-raw> lines are contained as the body of the block. For example:
+When combined with C<-raw>/C<-body> lines, the condition is placed first in a C<if>
+statement, and the C<-raw>/C<-body> lines are contained as the body of the block. For example:
 
     [DynamicPrereqs]
     -condition = $] > '5.020'
-    -raw = requires('1.003000')
+    -body = requires('1.003000')
 
 results in the F<Makefile.PL> snippet:
 
@@ -437,7 +451,7 @@ are now included automatically, when used).
 =head1 AVAILABLE SUBROUTINE DEFINITIONS
 
 A number of helper subroutines are available for use within your code inserted
-via C<-raw>, C<-raw_from_file>, or C<-condition> clauses. When used, their
+via C<-body>, C<-body_from_file>, C<-raw>, C<-raw_from_file>, or C<-condition> clauses. When used, their
 definition(s) will be included automatically in F<Makefile.PL> (as well as
 those of any other subroutines I<they> call); necessary prerequisite modules
 will be added to C<configure requires> metadata.
@@ -599,7 +613,7 @@ There is also a mailing list available for users of this distribution, at
 L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
-irc://irc.perl.org/#distzilla.
+L<irc://irc.perl.org/#distzilla>.
 
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
